@@ -1,7 +1,7 @@
 var results = {
 
 "AI-NeuralNet-BackProp-0.89": [
-  {status:"PASS",id:"2965930",perl:"5.10.0",osname:"linux",ostext:"Linux",osvers:"2.6.24-etchnhalf.1-amd64",archname:"x86_64-linux-thread-multi-ld",perlmat:"rel"}
+  {status:"PASS",id:"2965930",perl:"5.10.0",osname:"linux",ostext:"LINUX",osvers:"2.6.24-etchnhalf.1-amd64",archname:"x86_64-linux-thread-multi-ld",perlmat:"rel"}
 ],
 
 "AI-NeuralNet-BackProp-0.77": [
